package com.taboola.flutter;

import android.os.Build;

import java.util.HashMap;
import java.util.Map;

/**
 * Exposes device information to the Flutter side from native Build.
 * This class provides methods to retrieve various device information such as manufacturer, model,
 * Android OS version, base OS version (if available), security patch level (if available), and more.
 * Information is retrieved directly from the native Android Build class.
 */
public class TaboolaDeviceInfo {

    private static final String manufacturer = "manufacturer";
    private static final String modelKey = "model";
    private static final String baseOSKey = "baseOS";
    private static final String releaseKey = "release";
    private static final String versionKey = "version";
    private static final String previewSdkIntKey = "previewSdkInt";
    private static final String securityPatchKey = "securityPatch";


    public Map<String, Object> getDeviceInfo() {
        Map<String, Object> deviceInfoData = new HashMap<>();
        deviceInfoData.put(manufacturer, Build.MANUFACTURER);
        deviceInfoData.put(modelKey, Build.MODEL);
        Map<String, Object> version = new HashMap<>();
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            version.put(baseOSKey, Build.VERSION.BASE_OS);
            version.put(previewSdkIntKey, Build.VERSION.PREVIEW_SDK_INT);
            version.put(securityPatchKey, Build.VERSION.SECURITY_PATCH);
        }
        version.put(releaseKey, Build.VERSION.RELEASE);
        deviceInfoData.put(versionKey, version);
        return deviceInfoData;
    }


}
