import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/classic/taboola_classic.dart';
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart'
    as PublisherProperties;
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

class AliTest extends StatelessWidget {
  final bool isKeepAlive;

  AliTest(this.isKeepAlive);

  late ScaffoldMessengerState
      _scaffoldMessenger; //A reference to ScaffoldMessenger to allow sending Snackbar messages

  @override
  Widget build(BuildContext context) {
    Taboola.init(PublisherInfo(PublisherProperties.publisher));
    TaboolaClassicBuilder taboolaStandardBuilder =
        Taboola.getTaboolaClassicBuilder(
            PublisherProperties.pageUrl, PublisherProperties.pageType);

    TaboolaClassicListener taboolaStandardListener = TaboolaClassicListener(
        taboolaDidResize,
        taboolaDidShow,
        taboolaDidFailToLoad,
        taboolaDidClickOnItem);
    TaboolaClassicUnit taboolaStandard = taboolaStandardBuilder.build(
        PublisherProperties.placement,
        PublisherProperties.mode,
        true,
        taboolaStandardListener,keepAlive: isKeepAlive);

    //Define ScaffoldMessanger
    _scaffoldMessenger = ScaffoldMessenger.of(context);

    /// At the moment, SingleChildScrollView fits more our Widgets. In general, and any Feed integration, we recommend using CustomScrollView for NestedScrolling solution.
    return SingleChildScrollView(
        controller: taboolaStandard.scrollController,
        //Using SingleChildScrollView requires using 'controller: taboolaStandard.scrollController', otherwise the y value of Taboola's Unit rect does not get updated properly by Flutter.
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.center,
            mainAxisSize: MainAxisSize.max,
            children: [
              Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Wrap( children: [
                    Text(
                      "Test text..",
                      maxLines: 3,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(fontSize: 30.0),
                    ),
                    const SizedBox(
                      height: 20.0,
                    ),
                    Wrap(
                      children: [
                        Wrap(
                          children: [
                            Icon(
                              FontAwesomeIcons.userAlt,
                              size: 20.0,
                            ),
                            const SizedBox(
                              width: 3.0,
                            ),
                            Text(
                              "Another test text..",
                              style: TextStyle(fontSize: 18.0),
                            ),
                          ],
                        ),
                        Row(
                          children: [
                            Icon(
                              FontAwesomeIcons.clock,
                              size: 20.0,
                            ),
                            const SizedBox(
                              width: 3.0,
                            ),
                            Text(
                              "Another test text..",
                              style: TextStyle(fontSize: 18.0),
                            ),
                          ],
                        ),
                        Row(
                          children: [
                            Icon(
                              FontAwesomeIcons.calendarAlt,
                              size: 20.0,
                            ),
                            const SizedBox(
                              width: 3.0,
                            ),
                            Text(
                              "Another test text..",
                              style: TextStyle(fontSize: 18.0),
                            ),
                          ],
                        ),
                      ],
                    ),
//                    BlocConsumer<DetailsCubit, DetailsState>(
//                        listener: (ctx1, detState) {
//                          print('detail cubit loaded');
//                          _shareBloc.add(
//                            DownloadShareCountEvent(
//                                postId: this.widget.post.id.toString()),
//                          );
//
//                          _commentsBloc.add(DownloadComments(
//                              postId: widget.post.id.toString()));
//                        }, builder: (ctx, detailsState) {
//                      if (detailsState is ContentListLoaded) {
//                        return _getHtmlContentBody(
//                            detailsState.contentList);
//                      } else {
//                        return SizedBox.shrink();
//                      }
//                    }),
                    const SizedBox(
                      height: 10.0,
                    ),
//                    NativeAdWidget(
//                      adUnit: _admobService.getPostNative(),
//                    ),
                    const SizedBox(
                      height: 200.0,
                    ),
                    taboolaStandard,
                  ]))
            ]));
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(
      String placement, String itemId, String clickUrl, bool organic) {
    print(
        "publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    if (organic) {
      _showToast("Publisher opted to open click but didn't actually open it.");
    } else {
      _showToast(
          "Publisher opted to open clicks but the item is Sponsored, SDK retains control.");
    }
    return false;
  }

  void _showToast(String text) {
    _scaffoldMessenger.showSnackBar(
      SnackBar(
        content: Text(text),
        action: SnackBarAction(
            label: 'OK', onPressed: _scaffoldMessenger.hideCurrentSnackBar),
      ),
    );
  }
}
