import 'package:flutter/material.dart';
import 'package:taboola_sdk/classic/taboola_classic.dart';
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';
import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart'
    as PublisherProperties;

class SingleChildScrollViewTest extends StatelessWidget {
  final bool isKeepAlive;

  SingleChildScrollViewTest(this.isKeepAlive);

  late ScaffoldMessengerState
      _scaffoldMessenger; //A reference to ScaffoldMessenger to allow sending Snackbar messages

  @override
  Widget build(BuildContext context) {
    Taboola.init(PublisherInfo(PublisherProperties.publisher));
    TaboolaClassicBuilder taboolaClassicBuilder =
        Taboola.getTaboolaClassicBuilder(
            PublisherProperties.pageUrl, PublisherProperties.pageType);

    TaboolaClassicListener taboolaClassicListener = TaboolaClassicListener(
        taboolaDidResize,
        taboolaDidShow,
        taboolaDidFailToLoad,
        taboolaDidClickOnItem);
    TaboolaClassicUnit taboolaClassic = taboolaClassicBuilder.build(
        PublisherProperties.placement_widget,
        PublisherProperties.mode,
        true,
        taboolaClassicListener,
        keepAlive: isKeepAlive);

    //Define ScaffoldMessanger
    _scaffoldMessenger = ScaffoldMessenger.of(context);

    /// At the moment, SingleChildScrollView fits more our Widgets. In general, and any Feed integration, we recommend using CustomScrollView for NestedScrolling solution.
    return SingleChildScrollView(
        controller: taboolaClassic.scrollController,
        //Using SingleChildScrollView requires using 'controller: taboolaStandard.scrollController', otherwise the y value of Taboola's Unit rect does not get updated properly by Flutter.
        child: Column(children: [
          _getContentColumn(),
          taboolaClassic,
        ]));
  }

  Widget _buildSeparator() {
    return Container(
      height: 8,
      width: 512,
      color: Color.fromARGB(255, 50, 50, 50),
    );
  }

  Widget _getContentColumn() {
    return Center(
      child: Column(
          mainAxisAlignment: MainAxisAlignment.start,
          mainAxisSize: MainAxisSize.max,
          crossAxisAlignment: CrossAxisAlignment.stretch,
          children: [
            Text(
              'This Example does not scroll inside the WebView content and fits "Taboola Widget" scenarios. For "Taboola Feed" integrations, we recommend using CustomScrollView for NestedScrolling solution',
            ),
            _buildSeparator(),
            _buildTaboolaFlutterLogo(),
            _buildSeparator(),
            _buildSeparator(),
            _buildTaboolaFlutterLogo(),
            _buildSeparator(),
            _buildSeparator(),
            _buildTaboolaFlutterLogo(),
            _buildSeparator(),
          ]),
    );
  }

  Widget _buildTaboolaFlutterLogo() {
    return Container(
      color: Color.fromARGB(255, 230, 241, 255),
      height: 300,
      padding: EdgeInsets.all(32.0),
      child: Image(
        image: AssetImage('images/flutter_taboola_logo.png'),
        alignment: Alignment.center,
      ),
    );
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(
      String placement, String itemId, String clickUrl, bool organic) {
    print(
        "publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    if (organic) {
      _showToast("Publisher opted to open click but didn't actually open it.");
    } else {
      _showToast(
          "Publisher opted to open clicks but the item is Sponsored, SDK retains control.");
    }
    return false;
  }

  void _showToast(String text) {
    _scaffoldMessenger.showSnackBar(
      SnackBar(
        content: Text(text),
        action: SnackBarAction(
            label: 'OK', onPressed: _scaffoldMessenger.hideCurrentSnackBar),
      ),
    );
  }
}
