import 'package:flutter/material.dart';

import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';
import 'package:taboola_sdk/classic/taboola_classic.dart';
import 'package:taboola_sdk/utils/logger.dart';

class TaboolaCustomScrollviewScreen extends StatelessWidget {
  late TaboolaClassicBuilder _taboolaClassicBuilder;
  late TaboolaClassicListener _taboolaClassicListener;

  late TaboolaClassicUnit _taboolaStandard;

  TaboolaCustomScrollviewScreen(String publisher, String pageUrl,
      String pageType, String placement, String mode, bool isKeepAlive) {
    Taboola.init(PublisherInfo(publisher));
    _taboolaClassicBuilder =
        Taboola.getTaboolaClassicBuilder(pageUrl, pageType);
    _taboolaClassicListener = TaboolaClassicListener(taboolaDidResize,
        taboolaDidShow, taboolaDidFailToLoad, taboolaDidClickOnItem);
    _taboolaStandard = _taboolaClassicBuilder.build(
        placement, mode, true, _taboolaClassicListener,
        keepAlive: isKeepAlive);
  }

  @override
  Widget build(BuildContext context) {
    return CustomScrollView(
      controller: _taboolaStandard.scrollController,
      slivers: <Widget>[
        SliverList(delegate: new SliverChildListDelegate(_buildList(20))),
        SliverToBoxAdapter(
          child: _taboolaStandard,
        ),
      ],
    );
  }

  /// Sample content.
  List<Widget> _buildList(int count) {
    List<Widget> listItems = [];

    for (int i = 0; i < count; i++) {
      listItems.add(
        Padding(
          padding: EdgeInsets.all(20.0),
          child: Text(
            'Item ${i.toString()}',
            style: TextStyle(fontSize: 25.0),
          ),
        ) as Widget,
      );
    }

    return listItems;
  }

  List<Widget> addEmulatorWarning(List<Widget> listItems) {
    listItems.add(new Padding(
        padding: new EdgeInsets.all(20.0),
        child: new Text(
          'Warning: current version of Taboola Flutter SDK has WebView-Native scroll switch issues on emulators. Please debug on a real device.',
        )));

    return listItems;
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    Logger.log("taboolaDidShow");
  }

  void taboolaDidResize(String placement, double height) {
    Logger.log("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(
      String placement, String itemId, String clickUrl, bool organic) {
    print(
        "publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    return true;
  }
}
