import 'dart:collection';
import 'dart:math';
import 'package:taboola_sdk/classic/taboola_classic.dart';

import 'package:flutter/material.dart';
import 'package:taboola_sdk/taboola.dart';
import 'package:taboola_sdk_example/DefaultProperties.dart'
    as DefaultProperties;
import 'package:taboola_sdk_example/MidArticleWithoutVideo.dart'
    as MidArticlePublisherProperties;
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';

class TaboolaDedupAndExtraPropertiesScreen extends StatefulWidget {
  final bool isKeepAlive;

  const TaboolaDedupAndExtraPropertiesScreen(this.isKeepAlive);

  _TaboolaDedupScreenState createState() => _TaboolaDedupScreenState();
}

class _TaboolaDedupScreenState
    extends State<TaboolaDedupAndExtraPropertiesScreen> {
  late ScaffoldMessengerState
      _scaffoldMessenger; //A reference to ScaffoldMessenger to allow sending Snackbar messages
  late TaboolaClassicUnit _firstWidget;
  bool _firstWidgetLoaded =
      false; // Indicate that first widget on the screen finish loading and we can call the second one
  late ScrollController _scrollController;
  late TaboolaClassicListener _taboolaClassicListener;
  late TaboolaClassicBuilder _taboolaClassicBuilder;
  late int _viewId;
  bool isShowTaboola = false;
  bool initWithExtraProperties = false;

  final globalExtraKeyController = TextEditingController();
  final globalExtraValueController = TextEditingController();

  final pageKeyTextInputController = TextEditingController();
  final pageValueTextInputController = TextEditingController();

  final unitKeyTextInputController = TextEditingController();
  final unitValueTextInputController = TextEditingController();

  void initTaboola() {
    var publisherExtraProps = HashMap<String, dynamic>();
    publisherExtraProps[globalExtraKeyController.text] = globalExtraValueController.text;
    if (initWithExtraProperties) {
      Taboola.init(PublisherInfo(DefaultProperties.publisher),
          extraProperties: publisherExtraProps);
    } else {
      Taboola.init(PublisherInfo(DefaultProperties.publisher));
    }
  }

  void initPage() {
    setState(() {
      _taboolaClassicListener = TaboolaClassicListener(taboolaDidResize,
          taboolaDidShow, taboolaDidFailToLoad, taboolaDidClickOnItem);
      _taboolaClassicBuilder = Taboola.getTaboolaClassicBuilder(
          DefaultProperties.pageUrl, DefaultProperties.pageType);
    });
  }

  void loadTaboolaUnits() {
    setState(() {
      isShowTaboola = true;
    });
  }

  void setPageExtraProps(TaboolaClassicBuilder page) {
    var unitExtraProps = HashMap<String, dynamic>();
    unitExtraProps[pageKeyTextInputController.text] =
        pageValueTextInputController.text;
    page.setPageExtraProperties(unitExtraProps);
  }

  void setUnitExtraProps(TaboolaClassicUnit unit) {
    var unitExtraProps = HashMap<String, dynamic>();
    unitExtraProps[unitKeyTextInputController.text] =
        unitValueTextInputController.text;
    _firstWidget.setUnitExtraProps(unitExtraProps);
  }

  void setGlobalExtraProps() {
    var publisherExtraProps = HashMap<String, dynamic>();
    publisherExtraProps[globalExtraKeyController.text] = globalExtraValueController.text;
    Taboola.setGlobalExtraProperties(publisherExtraProps);
  }

  /// Function build first widget if already build will return the same one.
  /// this is for preventing the first widget to recreate after it finished fetching data and we update layout to add new widgets
  void buildFirstWidget() {
    setState(() {
      _viewId = Random().nextInt(100);
      _firstWidget = _taboolaClassicBuilder.build(
          MidArticlePublisherProperties.dark_placement_widget,
          MidArticlePublisherProperties.dark_mode,
          true,
          _taboolaClassicListener,
          viewId: _viewId,
          keepAlive: widget.isKeepAlive);
    });
  }

  @override
  Widget build(BuildContext context) {
    //Define ScaffoldMessanger
    _scaffoldMessenger = ScaffoldMessenger.of(context);
    _scrollController = ScrollController();
    if (isShowTaboola) {
      return screenWithTaboolaUnits();
    } else {
      return buildExtraPropertiesSettingScreen();
    }
  }

  CustomScrollView screenWithTaboolaUnits(){
    if (!_firstWidgetLoaded) {
      return CustomScrollView(
        controller: _scrollController,
        slivers: [
          SliverToBoxAdapter(child: new Container(child: _firstWidget)),
        ],
      );
    } else {
      return CustomScrollView(
        controller: _scrollController,
        slivers: [
          SliverToBoxAdapter(child: new Container(child: _firstWidget)),
          SliverToBoxAdapter(
              child: new Container(
                  child: buildSecondWidget(
                      _taboolaClassicBuilder, _taboolaClassicListener))),
        ],
      );
    }
  }

  CustomScrollView buildExtraPropertiesSettingScreen(){
    return CustomScrollView(
      controller: _scrollController,
      slivers: [
        SliverToBoxAdapter(
          child: Container(
            child: Column(
              children: [
                ElevatedButton(
                  child: Text('Init Taboola'), // Add your label here
                  onPressed: () {
                    initTaboola();
                  },
                ),
                SwitchListTile(
                  title: const Text('Is test init with extraProperties?'),
                  // This bool value toggles the switch.
                  value: initWithExtraProperties,
                  activeColor: Colors.blueAccent,
                  onChanged: (bool value) {
                    // This is called when the user toggles the switch.
                    setState(() {
                      initWithExtraProperties = value;
                    });
                  },
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'GlobalExtaPropsKey',
                  ),
                  controller: globalExtraKeyController,
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'GlobalExtaPropsValue',
                  ),
                  controller: globalExtraValueController,
                ),
                ElevatedButton(
                  child: Text('Set global extraProps'), // Add your label here
                  onPressed: initWithExtraProperties ? null : () => setGlobalExtraProps(),
                ),
                ElevatedButton(
                  child: Text('Init page'), // Add your label here
                  onPressed: () {
                    initPage();
                  },
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'pageExtraPropsKey',
                  ),
                  controller: pageKeyTextInputController,
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'pageExtraPropsValue',
                  ),
                  controller: pageValueTextInputController,
                ),
                ElevatedButton(
                  child: Text('Set Page Extra Props'),
                  onPressed: () {
                    setPageExtraProps(_taboolaClassicBuilder);
                  },
                ),
                ElevatedButton(
                  child: Text('buildFirstWidget'), // Add your label here
                  onPressed: () {
                    buildFirstWidget();
                  },
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'unitExtraPropsKey',
                  ),
                  controller: unitKeyTextInputController,
                ),
                TextField(
                  decoration: InputDecoration(
                    border: OutlineInputBorder(),
                    hintText: 'unitExtraPropsValue',
                  ),
                  controller: unitValueTextInputController,
                ),
                ElevatedButton(
                  child: Text('Set first unit extraProps'),
                  // Add your label here
                  onPressed: () {
                    setUnitExtraProps(_firstWidget);
                  },
                ),
                ElevatedButton(
                  child: Text('Load Taboola'), // Add your label here
                  onPressed: () {
                    loadTaboolaUnits();
                  },
                ),
              ],
            ),
          ),
        ),
      ],
    );
  }

  TaboolaClassicUnit buildSecondWidget(
      TaboolaClassicBuilder taboolaClassicBuilder,
      TaboolaClassicListener taboolaClassicListener) {
    return taboolaClassicBuilder.build(DefaultProperties.placement,
        DefaultProperties.mode, true, taboolaClassicListener,
        viewId: _viewId, keepAlive: widget.isKeepAlive);
  }

  //Taboola Standard listeners
  void taboolaDidShow(String placement) {
    print("taboolaDidShow");
    if (placement == MidArticlePublisherProperties.placement_widget) {
      setState(() {
        _firstWidgetLoaded = true;
      });
    }
  }

  void taboolaDidResize(String placement, double height) {
    print("publisher did get height $height");
  }

  void taboolaDidFailToLoad(String placement, String error) {
    print("publisher placement:$placement did fail with an error:$error");
  }

  bool taboolaDidClickOnItem(
      String placement, String itemId, String clickUrl, bool organic) {
    print(
        "publisher did click on item: $itemId with clickUrl: $clickUrl in placement: $placement of organic: $organic");
    if (organic) {
      _showToast("Publisher opted to open click but didn't actually open it.");
    } else {
      _showToast(
          "Publisher opted to open clicks but the item is Sponsored, SDK retains control.");
    }
    return false;
  }

  void _showToast(String text) {
    _scaffoldMessenger.showSnackBar(
      SnackBar(
        content: Text(text),
        action: SnackBarAction(
            label: 'OK', onPressed: _scaffoldMessenger.hideCurrentSnackBar),
      ),
    );
  }
}
