import 'dart:collection';

import 'package:flutter/cupertino.dart';
import 'package:taboola_sdk/publisher_info.dart';
import 'package:taboola_sdk/classic/taboola_classic.dart';
import 'package:taboola_sdk/classic/taboola_classic_listener.dart';
import 'package:taboola_sdk/utils/text_utils.dart';

class TaboolaClassicBuilder {
  /// Constructor
  late PublisherInfo _publisherInfo;
  late String _pageUrl;
  late String _pageType;
  late HashMap<String, dynamic> _unrecognizedPageExtraPropertiesManager;

  /// Optional params
  String _pageId = "auto"; //default value
  String _targetType = "mix";

  TaboolaClassicBuilder(PublisherInfo _publisherInfo, String pageUrl,
      String pageType, unrecognizedGlobalExtraPropertiesManager) {
    this._publisherInfo = _publisherInfo;
    this._pageType = pageType;
    this._pageUrl = pageUrl;
    this._unrecognizedPageExtraPropertiesManager =
    new HashMap<String, dynamic>();
    setPageExtraProperties(unrecognizedGlobalExtraPropertiesManager);
  }

  setPageExtraProperties(HashMap<String, dynamic> extraProperties) {

    if(extraProperties.isEmpty) {
      return;
    }

    for (var property in extraProperties.entries) {
      var key = property.key;
      var value = property.value;
      if (TextUtils.isEmptyOrNull(key) ||
          (value is String && TextUtils.isEmptyOrNull(value))) {
        continue;
      }
      _unrecognizedPageExtraPropertiesManager[key] = value;
    }
  }

  /// Builder
  TaboolaClassicUnit build(String placement, String mode, bool isFeed,
      TaboolaClassicListener taboolaClassicListener,
      {int? viewId, ScrollController? scrollController, bool? keepAlive}) {
    if (_publisherInfo == null) {
      throw ('PublisherInfo is null, did you call Taboola init?');
    }

    return TaboolaClassicUnit(
        _publisherInfo.publisherId,
        mode,
        placement,
        _pageUrl,
        _pageType,
        _pageId,
        _targetType,
        isFeed,
        taboolaClassicListener,
        _unrecognizedPageExtraPropertiesManager,
        viewId: viewId,
        scrollController: scrollController,
        keepAlive: keepAlive);
  }
}
