import 'base_device.dart';

class AndroidDevice implements BaseDeviceInfo {
  AndroidDevice({
    required this.version,
    this.manufacturer,
    this.model,
  });

  final AndroidBuildVersion version;

  final String? manufacturer;

  final String? model;

  static const String versionKey = 'version';
  static const String manufacturerKey = 'manufacturer';

  @override
  Map<String, dynamic> toMap() {
    return {
      BaseDeviceInfo.modelKey: model,
      versionKey: version.toMap(),
      manufacturerKey: manufacturer,
    };
  }

  @override
  toString() {
    return 'AndroidDevice { model: $model, version: $version, manufacturer: $manufacturer }';
  }

  static AndroidDevice fromMap(Map<String, dynamic> map) {
    return AndroidDevice(
      version: AndroidBuildVersion._fromMap(
          map['version']?.cast<String, dynamic>() ?? {}),
      manufacturer: map['manufacturer'],
      model: map['model'],
    );
  }
}

class AndroidBuildVersion {
  const AndroidBuildVersion._({
    this.release,
  });

  final String? release;

  Map<String, dynamic> toMap() {
    return {
      'release': release,
    };
  }

  static AndroidBuildVersion _fromMap(Map<String, dynamic> map) {
    return AndroidBuildVersion._(
      release: map['release'],
    );
  }

  @override
  toString() {
    return 'AndroidBuildVersion { release: $release }';
  }
}
