// Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'dart:async';

import 'package:taboola_sdk/native_plugin/taboola_package_info_platform_interface.dart';

class TaboolaPackageInfo {
  TaboolaPackageInfo({
    required this.appName,
    required this.packageName,
    required this.version,
  });

  static TaboolaPackageInfo? _packageInfoData;

  static Future<TaboolaPackageInfo> getAllPackageInfo() async {
    if (_packageInfoData != null) {
      return _packageInfoData!;
    }

    final packageInfo = await TaboolaPackageInfoPlatform.instance.getAllPackageInfo();

    _packageInfoData = TaboolaPackageInfo(
      appName: packageInfo.appName,
      packageName: packageInfo.packageName,
      version: packageInfo.version,
    );

    return _packageInfoData!;
  }

  /// `CFBundleDisplayName/CFBundleName` iOS, `application/label` Android.
  final String appName;

  /// `bundleIdentifier` iOS, `getPackageName` Android.
  final String packageName;

  /// `CFBundleShortVersionString` iOS, `versionName` Android.
  final String version;

  /// Overwrite equals for value equality
  @override
  bool operator == (Object other) =>
      identical(this, other) ||
          other is TaboolaPackageInfo &&
              runtimeType == other.runtimeType &&
              appName == other.appName &&
              packageName == other.packageName &&
              version == other.version;

  @override
  int get hashCode =>
      appName.hashCode ^
      packageName.hashCode ^
      version.hashCode;

  @override
  String toString() {
    return 'Info(appName: $appName packageName: $packageName, version: $version)';
  }
}
