library taboola;

import 'dart:collection';

import 'package:taboola_sdk/publisher_info.dart';
import 'package:taboola_sdk/classic/taboola_classic_builder.dart';
import 'package:taboola_sdk/utils/logger.dart';
import 'package:taboola_sdk/utils/text_utils.dart';

export 'package:taboola_sdk/publisher_info.dart';
export 'package:taboola_sdk/classic/taboola_classic_builder.dart';

class Taboola {
  static late PublisherInfo _publisherInfo;
  static HashMap<String, dynamic> _unrecognizedGlobalExtraProperties =
      new HashMap<String, dynamic>();

  /// Initializes the Taboola SDK with the provided [PublisherInfo] and optional extra properties.
  ///
  /// Use this method to configure the Taboola SDK with your [PublisherInfo]. You can also
  /// provide extra properties as a [HashMap<String, dynamic>], but it is not recommended
  /// to set them here. Instead, consider using the [setGlobalExtraProperties] method to
  /// set global extra properties for the Taboola SDK.
  ///
  /// [publisherInfo]: Information about your Taboola publisher account.
  /// [extraProperties]: Optional extra properties to configure the Taboola SDK.
  static init(PublisherInfo publisherInfo,
      {HashMap<String, dynamic>? extraProperties}) {
    HashMap<String, dynamic> extraProp = extraProperties == null
        ? new HashMap<String, dynamic>()
        : extraProperties;

    Taboola.setGlobalExtraProperties(extraProp);
    Taboola._publisherInfo = publisherInfo;
  }

  static setGlobalExtraProperties(HashMap<String, dynamic> extraProperties) {
    if (extraProperties.isEmpty) {
      return;
    }

    for (var property in extraProperties.entries) {
      var key = property.key;
      var value = property.value;
      if (TextUtils.isEmptyOrNull(key) ||
          (value is String && TextUtils.isEmptyOrNull(value))) {
        continue;
      }
      _unrecognizedGlobalExtraProperties[key] = value;
    }
  }

  static TaboolaClassicBuilder getTaboolaClassicBuilder(
      String pageUrl, String pageType) {
    return new TaboolaClassicBuilder(
      _publisherInfo,
      pageUrl,
      pageType,
      _unrecognizedGlobalExtraProperties,
    );
  }

  static void setLogsEnabled(bool enabled) {
    Logger.taboolaLogsEnabled = enabled;
  }
}
